@@ -497,7 +497,7 @@ separately.
 
 =item B<pgpmode=>I<mode>
 
-Set the PGP/GPG signature verification I<mode>.
+Set the OpenPGP signature verification I<mode>.
 
 =over
 
@@ -568,7 +568,7 @@ npmjs.com:
 
 =item B<decompress>
 
-Decompress compressed archive before the pgp/gpg signature verification.
+Decompress compressed archive before the OpenPGP signature verification.
 
 =item B<bare>
 
@@ -861,8 +861,8 @@ tarball href and the signature file is tried to be downloaded from it.
 
 If the B<pgpsigurlmangle> rule doesn't exist, B<uscan> warns user if the
 matching upstream signature file is available from the same URL with their
-filename being suffixed by the 5 common suffix B<asc>, B<gpg>, B<pgp>, B<sig>
-and B<sign>. (You can avoid this warning by setting B<pgpmode=none>.)
+filename being suffixed by the 5 common suffix B<asc>, B<sig>, B<sign>,
+B<pgp> and B<gpg>. (You can avoid this warning by setting B<pgpmode=none>.)
 
 If the signature file is downloaded, the downloaded upstream tarball is checked
 for its authenticity against the downloaded signature file using the armored keyring
@@ -1552,7 +1552,7 @@ servers.  You must verify the downloaded OpenPGP key using its full fingerprint
 value which you know is the trusted one.
 
 The armored keyring file F<debian/upstream/signing-key.asc> can be created by
-using the B<gpg> (or B<gpg2>) command as follows.
+using the B<gpg> command as follows.
 
   $ gpg --recv-keys "C77E2D6872543FAF"
   ...
